==> f-r-eiertag_0.4-2.tar.gz: f-r-eiertag-0.4/src/opt/frei/frei.py <==
#!/usr/bin/env python
#-*- coding: utf-8 -*-

##################################################################################################################################		
## Copyleft (Ɔ) 2011: Code is released under the conditions of the GNU General Public License Version 3. 			##		
## WARNING: Maybe the iCal files have got another license, so they are maybe not free and/or compatible to GPL Version 3.	##
## 																##
## Copyleft (Ɔ) 2011: Der Code wird unter den Bedingungen der GNU General Public License Version 3 lizensiert.			##
## ACHTUNG: Die iCal Daten könnten eine (andere) Lizenz haben, also unfrei und/oder nicht GPL3 kompatibel sein.			##
## 																##
## Author/Autor: 		Gabriel Böhme											##
## E-Mail: 			m.gabriel.boehme@googlemail.com									##
## Datasource/Datenquelle: 	www.schulferien.org/iCal									##
##																##
## Discription: This little Maemo5-PyQt-App can show you all free daysat germany in the year: holiday (school), and also 	##
## public holiday. The data is parsed from iCal files, that you can download for free at schulferien.org/iCal			##
## 																##
## Beschreibung: Diese kleine Maemo5-PyQt-App kann alle deutschen Feiertage und Schulferien anzeigen. Als Datenquelle dienen 	##
## die iCal Datensätze von schulferien.org, welche zum freien Download angeboten werden. 					##	##																##
##################################################################################################################################

#Importe
import sys
from datetime import date
from PyQt4.QtCore import Qt, QString
from PyQt4.QtGui import QApplication, QMainWindow, QLabel, QComboBox, QMessageBox
from PyQt4.uic import loadUi

#Klasse für das Hauptfenster - stammt von QMainWindow
class freiWindow(QMainWindow):
	def __init__(self):
		QMainWindow.__init__(self)
		self.ui = loadUi('frei.ui')
		self.ui.showFullScreen()
		self.ui.setAttribute(Qt.WA_Maemo5PortraitOrientation, True)
		
		self.index_load() #um MainWindow sauber zu halten!	
		self.ui.stackedWidget.setCurrentIndex(0)
		self.ui.such_button.clicked.connect(self.such_button)
		self.ui.exit_button.clicked.connect(self.ende)
		self.ui.ueber_button.clicked.connect(self.zeige_ueber)
		self.ui.back_p2.clicked.connect(self.back)
		self.ui.back_p3.clicked.connect(self.back)

###################################################################################################

	#Funktion für Zurück-Pfeile
	def back(self):
		self.ui.stackedWidget.setCurrentIndex(0)

###################################################################################################

	#Funktion lädt gespeicherte 'Indexe' hier realisiert um MainWindow 'sauber' zu halten
	def index_load(self):
		try:			
			#Einlesen der settings.ini -> gespeicherte ComboBox Positionen
			load = file('~/.config/settings.cfg', 'r')
			index = []
			i = 0
		
			#einlesen per Liste: 0 = Jahr, 1 = Bundesland, 2 = Ferien/Feiertage
			while i != 3:
				sets = load.readline()
				index.append(sets)
				i += 1

			#Umwandlung in int's geht nicht während setCurrentIndex - daher hier
			index1 = int(index[0])
			index2 = int(index[1])
			index3 = int(index[2])

			#setzen der zuvor gespeicherten Indexe
			self.ui.jahr_box.setCurrentIndex(index1)
			self.ui.bland_box.setCurrentIndex(index2)
			self.ui.frei_box.setCurrentIndex(index3)
		except:
			print "Problem mit der settings.cfg"

###################################################################################################

	#Funktion für Such-Taste
	def such_button(self):
		#Abfrage der Comboboxen
		jahr = self.ui.jahr_box.currentText()
		bundesland = self.ui.bland_box.currentText()
		frei = self.ui.frei_box.currentText()

		#Abfrage der Combobox-Index-Nummern, zur Speicherung
		jahr_save = self.ui.jahr_box.currentIndex()
		bundesland_save = self.ui.bland_box.currentIndex()
		frei_save = self.ui.frei_box.currentIndex()

		#Speicherung der letzten Suche
		try:		
			save = file('~/.config/settings.cfg', 'w')
			save.write('%s\n%s\n%s\n' % (jahr_save, bundesland_save, frei_save))
			save.close()
		except:
			print "Probleme mit der settings.cfg"

		#Überschriften (Page2,3) werden vorsorglich mit Bundesland und Jahr betitelt
		self.ui.title_label_p2.setText('%s | %s :' % (bundesland, jahr))
		self.ui.title_label_p3.setText('Feiertage | %s | %s :' % (bundesland, jahr))
	
		#Replacment um Dateneinlesen zu können und Probleme mit Coding zu vermeiden		
		bundesland = bundesland.replace(u'ü', 'ue')
		bundesland = bundesland.replace('-', '_')

		#Passend zur Wahl wird die richtige Funktion aufgerufen!
		if frei == 'Schulferien':
			self.ui.stackedWidget.setCurrentIndex(1)
			self.parse_ferien(jahr, bundesland)

		if frei == 'gesetzliche Feiertage':
			gesetz = True
			self.ui.stackedWidget.setCurrentIndex(2)
			self.parse_feiertage(jahr, bundesland, gesetz)

		if frei == 'alle Feiertage':
			gesetz = False
			self.ui.stackedWidget.setCurrentIndex(2)
			self.parse_feiertage(jahr,bundesland, gesetz)

###################################################################################################

	def parse_ferien(self, jahr, bundesland):
		#löscht die list_view
		self.ui.ferien_list.clear()
		#bestimmt die Datei, an Hand der Variablen aus den Comboboxen.
		#Die Dateien liegen dann unter data/<jahr>/ferien/Ferien_<bundesland>_<jahr>.ics liegen!
		termine = file('data/%s/ferien/Ferien_%s_%s.ics' % (jahr, bundesland, jahr), 'r')

		for start_ende in termine.readlines():
			#Unter SUMMARY liegen die Namen der Ferien, werden hier geparst und ohne Bundesland-Namen wieder ausgegeben
			if start_ende.startswith('SUMMARY:'):
				summary = start_ende[8:-1]
				summary = summary.replace('ue', u'ü')
				summary = summary[:len(summary)-len(bundesland)]
				
				self.ui.ferien_list.addItem(summary)

			#Start Datum sowie Enddatum der Ferien, durch for-Schleife immer im Wechsel, in der Liste!
			if start_ende.startswith('DTSTART;VALUE=DATE:'):
				datum_start = start_ende[19:27]
				ds = datum_start[6:8] 
				ms = datum_start[4:6] 
				ys = datum_start[0:4]

			if start_ende.startswith('DTEND;VALUE=DATE:'):
				datum_ende = start_ende[17:25]
				de = datum_ende[6:8] 
				me = datum_ende[4:6] 
				ye = datum_ende[0:4]

				self.ui.ferien_list.addItem('%s.%s.%s - %s.%s.%s' % (ds, ms, ys, de, me, ye))

###################################################################################################

	def parse_feiertage(self, jahr, bundesland, gesetz):
		#löscht die list_view
		self.ui.feiertag_list.clear()
		#bestimmt die Datei, an Hand der Variablen aus den Comboboxen.
		#Die Dateien liegen dann unter data/<jahr>/feiertage/Ferien_<bundesland>_<jahr>.ics liegen, unterscheidet nach gesetzlich oder nicht!
		if gesetz == True:
			termine = file('data/%s/feiertage/Feiertage_%s_%s.ics' % (jahr, bundesland, jahr), 'r')

		elif gesetz == False:
			termine = file('data/%s/feiertage/Feiertage_%s.ics' % (jahr, jahr), 'r')

		for start_ende in termine.readlines():
			#Unter SUMMARY liegen die Namen der Feiertage, werden hier geparst und ausgegeben.
			if start_ende.startswith('SUMMARY:'):
				summary = start_ende[8:-1]
			
				if summary != 'Volkstrauertag':
					summary = summary.replace('ue', u'ü')
					summary = summary.replace('ae', u'ä')
					summary = summary.replace('oe', u'ö')

				self.ui.feiertag_list.addItem("%s:" % summary)

			#Datum der Feiertage
			if start_ende.startswith('DTSTART;VALUE=DATE:'):
				datum_start = start_ende[19:27]
				ds = datum_start[6:8] 
				ms = datum_start[4:6] 
				ys = datum_start[0:4]
				#Bestimmung des Wochentages mit datetime.weekday() Funktion
				tag = ["Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag", "Sonntag"][date(int(ys), int(ms), int(ds)).weekday()]

				self.ui.feiertag_list.addItem('%s, %s.%s.%s' % (tag, ds, ms, ys))

###################################################################################################

	def zeige_ueber(self):
        	QMessageBox.about(self, 
                          u"Über diese App",u"""<b>F(r)eiertag</b>
                          <p>Diese App kann sowohl deutsche Feiertage als auch Schulferien anzeigen.
				Die Daten werden von schulferien.org bezogen.
				<p>Der Quellcode steht unter GPL Version 3.""")

###################################################################################################
	
	#Beenden!
	def ende(self):
		exit(self)

###################################################################################################

#Starten des Programms
if __name__ == '__main__':
	#Qt Umgebung
	app = QApplication(sys.argv)
	#Objekt (Fenster) wird aus Klasse geschaffen
	fenster = freiWindow()
	#START
	sys.exit(app.exec_())

==> f-r-eiertag_0.5-1.tar.gz: f-r-eiertag-0.5/src/opt/frei/frei.py <==
#!/usr/bin/env python
#-*- coding: utf-8 -*-

##################################################################################################################################		
## Copyleft (Ɔ) 2011: Code is released under the conditions of the GNU General Public License Version 3. 			##		
## WARNING: Maybe the iCal files have got another license, so they are maybe not free and/or compatible to GPL Version 3.	##
## 																##
## Copyleft (Ɔ) 2011: Der Code wird unter den Bedingungen der GNU General Public License Version 3 lizensiert.			##
## ACHTUNG: Die iCal Daten könnten eine (andere) Lizenz haben, also unfrei und/oder nicht GPL3 kompatibel sein.			##
## 																##
## Author/Autor: 		Gabriel Böhme											##
## E-Mail: 			m.gabriel.boehme@googlemail.com									##
## Datasource/Datenquelle: 	www.schulferien.org/iCal									##
##																##
## Discription: This little Maemo5-PyQt-App can show you all free daysat germany in the year: holiday (school), and also 	##
## public holiday. The data is parsed from iCal files, that you can download for free at schulferien.org/iCal			##
## 																##
## Beschreibung: Diese kleine Maemo5-PyQt-App kann alle deutschen Feiertage und Schulferien anzeigen. Als Datenquelle dienen 	##
## die iCal Datensätze von schulferien.org, welche zum freien Download angeboten werden. 					##	##																##
##################################################################################################################################

#Importe
import sys
from datetime import date
from PyQt4.QtCore import Qt, QString
from PyQt4.QtGui import QApplication, QMainWindow, QLabel, QComboBox, QMessageBox
from PyQt4.uic import loadUi

#Klasse für das Hauptfenster - stammt von QMainWindow
class freiWindow(QMainWindow):
	def __init__(self):
		QMainWindow.__init__(self)
		self.ui = loadUi('frei.ui')
		self.ui.showFullScreen()
		#self.ui.setAttribute(Qt.WA_Maemo5PortraitOrientation, True)
		
		self.index_load() #um MainWindow sauber zu halten!	
		self.ui.stackedWidget.setCurrentIndex(0)
		self.ui.such_button.clicked.connect(self.such_button)
		self.ui.exit_button.clicked.connect(self.ende)
		self.ui.ueber_button.clicked.connect(self.zeige_ueber)
		self.ui.back_p2.clicked.connect(self.back)
		self.ui.back_p3.clicked.connect(self.back)

		self.ui.ferien_list.itemClicked.connect(self.test)

	def test(self):
		print "Ferien angeklickt"

###################################################################################################

	#Funktion für Zurück-Pfeile
	def back(self):
		self.ui.stackedWidget.setCurrentIndex(0)

###################################################################################################

	#Funktion lädt gespeicherte 'Indexe' hier realisiert um MainWindow 'sauber' zu halten
	def index_load(self):
		try:			
			#Einlesen der settings.ini -> gespeicherte ComboBox Positionen
			load = file('~/.config/freiertag/settings.cfg', 'r')
			index = []
			i = 0
		
			#einlesen per Liste: 0 = Jahr, 1 = Bundesland, 2 = Ferien/Feiertage
			while i != 3:
				sets = load.readline()
				index.append(sets)
				i += 1

			#Umwandlung in int's geht nicht während setCurrentIndex - daher hier
			index1 = int(index[0])
			index2 = int(index[1])
			index3 = int(index[2])

			#setzen der zuvor gespeicherten Indexe
			self.ui.jahr_box.setCurrentIndex(index1)
			self.ui.bland_box.setCurrentIndex(index2)
			self.ui.frei_box.setCurrentIndex(index3)
		except:
			print "Problem mit der settings.cfg"

###################################################################################################

	#Funktion für Such-Taste
	def such_button(self):
		#Abfrage der Comboboxen
		jahr = self.ui.jahr_box.currentText()
		bundesland = self.ui.bland_box.currentText()
		frei = self.ui.frei_box.currentText()

		#Abfrage der Combobox-Index-Nummern, zur Speicherung
		jahr_save = self.ui.jahr_box.currentIndex()
		bundesland_save = self.ui.bland_box.currentIndex()
		frei_save = self.ui.frei_box.currentIndex()

		#Speicherung der letzten Suche
		try:		
			save = file('~/.config/settings.cfg', 'w')
			save.write('%s\n%s\n%s\n' % (jahr_save, bundesland_save, frei_save))
			save.close()
		except:
			print "Probleme mit der settings.cfg"

		#Überschriften (Page2,3) werden vorsorglich mit Bundesland und Jahr betitelt
		self.ui.title_label_p2.setText('%s | %s :' % (bundesland, jahr))
		self.ui.title_label_p3.setText('Feiertage | %s | %s :' % (bundesland, jahr))
	
		#Replacment um Dateneinlesen zu können und Probleme mit Coding zu vermeiden		
		bundesland = bundesland.replace(u'ü', 'ue')
		bundesland = bundesland.replace('-', '_')

		#Passend zur Wahl wird die richtige Funktion aufgerufen!
		if frei == 'Schulferien':
			self.ui.stackedWidget.setCurrentIndex(1)
			self.parse_ferien(jahr, bundesland)

		if frei == 'gesetzliche Feiertage':
			gesetz = True
			self.ui.stackedWidget.setCurrentIndex(2)
			self.parse_feiertage(jahr, bundesland, gesetz)

		if frei == 'alle Feiertage':
			gesetz = False
			self.ui.stackedWidget.setCurrentIndex(2)
			self.parse_feiertage(jahr,bundesland, gesetz)

###################################################################################################

	def parse_ferien(self, jahr, bundesland):
		#löscht die list_view
		self.ui.ferien_list.clear()
		#bestimmt die Datei, an Hand der Variablen aus den Comboboxen.
		#Die Dateien liegen dann unter data/<jahr>/ferien/Ferien_<bundesland>_<jahr>.ics liegen!
		termine = file('data/%s/ferien/Ferien_%s_%s.ics' % (jahr, bundesland, jahr), 'r')

		for start_ende in termine.readlines():
			#Unter SUMMARY liegen die Namen der Ferien, werden hier geparst und ohne Bundesland-Namen wieder ausgegeben
			if start_ende.startswith('SUMMARY:'):
				summary = start_ende[8:-1]
				summary = summary.replace('ue', u'ü')
				summary = summary[:len(summary)-len(bundesland)]
				
				self.ui.ferien_list.addItem(summary)

			#Start Datum sowie Enddatum der Ferien, durch for-Schleife immer im Wechsel, in der Liste!
			if start_ende.startswith('DTSTART;VALUE=DATE:'):
				datum_start = start_ende[19:27]
				ds = datum_start[6:8] 
				ms = datum_start[4:6] 
				ys = datum_start[0:4]

			if start_ende.startswith('DTEND;VALUE=DATE:'):
				datum_ende = start_ende[17:25]
				de = datum_ende[6:8] 
				me = datum_ende[4:6] 
				ye = datum_ende[0:4]

				self.ui.ferien_list.addItem('%s.%s.%s - %s.%s.%s' % (ds, ms, ys, de, me, ye))

###################################################################################################

	def parse_feiertage(self, jahr, bundesland, gesetz):
		#löscht die list_view
		self.ui.feiertag_list.clear()
		#bestimmt die Datei, an Hand der Variablen aus den Comboboxen.
		#Die Dateien liegen dann unter data/<jahr>/feiertage/Ferien_<bundesland>_<jahr>.ics liegen, unterscheidet nach gesetzlich oder nicht!
		if gesetz == True:
			termine = file('data/%s/feiertage/Feiertage_%s_%s.ics' % (jahr, bundesland, jahr), 'r')

		elif gesetz == False:
			termine = file('data/%s/feiertage/Feiertage_%s.ics' % (jahr, jahr), 'r')

		for start_ende in termine.readlines():
			#Unter SUMMARY liegen die Namen der Feiertage, werden hier geparst und ausgegeben.
			if start_ende.startswith('SUMMARY:'):
				summary = start_ende[8:-1]
			
				if summary != 'Volkstrauertag':
					summary = summary.replace('ue', u'ü')
					summary = summary.replace('ae', u'ä')
					summary = summary.replace('oe', u'ö')

				self.ui.feiertag_list.addItem("%s:" % summary)

			#Datum der Feiertage
			if start_ende.startswith('DTSTART;VALUE=DATE:'):
				datum_start = start_ende[19:27]
				ds = datum_start[6:8] 
				ms = datum_start[4:6] 
				ys = datum_start[0:4]
				#Bestimmung des Wochentages mit datetime.weekday() Funktion
				tag = ["Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag", "Sonntag"][date(int(ys), int(ms), int(ds)).weekday()]

				self.ui.feiertag_list.addItem('%s, %s.%s.%s' % (tag, ds, ms, ys))

###################################################################################################

	def zeige_ueber(self):
        	QMessageBox.about(self, 
                          u"Über diese App",u"""<b>F(r)eiertag</b>
                          <p>Diese App kann sowohl deutsche Feiertage als auch Schulferien anzeigen.
				Die Daten werden von schulferien.org bezogen.
				<p>Der Quellcode steht unter GPL Version 3.""")

###################################################################################################
	
	#Beenden!
	def ende(self):
		exit(self)

###################################################################################################

#Starten des Programms
if __name__ == '__main__':
	#Qt Umgebung
	app = QApplication(sys.argv)
	#Objekt (Fenster) wird aus Klasse geschaffen
	fenster = freiWindow()
	#START
	sys.exit(app.exec_())
